use std::{path::Path, str::FromStr};

use clap_complete::Shell;

fn print_completions<G: clap_complete::Generator>(gen: G, cmd: &mut clap::Command) {
    clap_complete::generate(gen, cmd, cmd.get_name().to_string(), &mut std::io::stdout());
}

pub(crate) fn handle(shell: Option<Shell>, cmd: &mut clap::Command) {
    let env_shell = std::env::var("SHELL").unwrap();

    if let Some(shell) = shell {
        print_completions(shell, cmd);
    } else {
        let filename = Path::new(&env_shell).file_name().unwrap();
        match Shell::from_str(filename.to_str().unwrap()) {
            Ok(shell) => print_completions(shell, cmd),
            Err(err) => panic!("{}", err),
        }
    }
}
