use sea_orm::{sea_query::Table};
use sea_orm_migration::{MigrationTrait, MigrationName};
use sea_orm_migration::prelude::*;

pub struct Migration;

impl MigrationName for Migration {
    fn name(&self) -> &str {
        "m20220804_000001_create_user_table"
    }
}

#[async_trait::async_trait]
impl MigrationTrait for Migration {
    async fn up(&self, manager: & sea_orm_migration::SchemaManager) ->  Result<(),sea_orm::DbErr> {
        manager.create_table(
            Table::create()
                .table(User::Table)
                .col(ColumnDef::new(User::Id).integer().primary_key().auto_increment().not_null())
                .col(ColumnDef::new(User::Name).string().unique_key().not_null())
                .col(ColumnDef::new(User::Password).string().not_null())
                .to_owned()
        ).await
    }

    async fn down(&self, manager: & sea_orm_migration::SchemaManager) ->  Result<(),sea_orm::DbErr> {
        manager.drop_table(Table::drop().table(User::Table).to_owned()).await
    }
}

#[derive(Iden)]
pub enum User {
    Table,
    Id,
    Name,
    Password,
}